# frozen_string_literal: true

class Folder < Document
end
